==> mediawiki_1.19.1.orig.tar.gz: mediawiki-1.19.1/languages/messages/MessagesTi.php <==
<?php
/** Tigrinya (ትግርኛ)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Blake
 * @author Node ue
 * @author Teak
 */

$messages = array(
'underline-always' => 'ጥራይ',
'underline-never'  => 'ኣይትግበሩ',

# Dates
'sunday'    => 'ሰንበት',
'monday'    => 'ሰኑይ',
'tuesday'   => 'ሰሉስ',
'wednesday' => 'ረብዓ',
'thursday'  => 'ኃሙስ',
'friday'    => 'ዓርቢ',
'saturday'  => 'ቀዳም',
'sun'       => 'ሰንበ',
'mon'       => 'ሰኑይ',
'tue'       => 'ሠሉስ',
'wed'       => 'ረቡዕ',
'thu'       => 'ኃሙስ',
'fri'       => 'ዓርቢ',
'sat'       => 'ቀዳም',
'january'   => 'ትሪ',
'february'  => 'ለካቲት',
'march'     => 'መጋቢት',
'april'     => 'ሚያዝያ',
'may_long'  => 'ግንቦት',
'june'      => 'ሰነ',
'july'      => 'ሓምለ',
'august'    => 'ነሓሰ',
'september' => 'መስከረም',
'october'   => 'ጥቅምቲ',
'november'  => 'ኅዳር',
'december'  => 'ታኅሣሥ',
'jan'       => 'ጃንዩ',
'feb'       => 'ፌብሩ',
'mar'       => 'ማርች',
'apr'       => 'ኤፕረ',
'may'       => 'ሜይ',
'jun'       => 'ጁን',

'about'  => 'ብዛዕባ ብጠቅላላ',
'mypage' => 'ፅሑፈይ',

# Cologne Blue skin
'qbpageoptions' => 'ፅሑፍዚ',
'qbmyoptions'   => 'ፅሑፋተይ',

'help'          => 'ፍንጪ',
'search'        => 'ድሉይ',
'searchbutton'  => 'ድሉይ',
'history'       => 'ናይ ፅሑፍ ታሪኽ',
'history_short' => 'ታሪኽ',
'newpage'       => 'ሓዳስ ፅሑፍ',
'jumptosearch'  => 'ድሉይ',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'ብዛዕባ ዊኪፒዲያ ብጠቅላላ',
'mainpage'             => 'መበገሲ ገጽ',
'mainpage-description' => 'መበገሲ ገጽ',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'    => 'ፅሑፍ',
'nstab-user'    => 'ናይ ፅሑፍ ኣባል',
'nstab-project' => 'ናይ ፅሑፍ ፕሮጀክት',
'nstab-image'   => 'ምስሊ',

# Login and logout pages
'yourname'           => 'ናይ ኣባል ሽም:',
'loginlanguagelabel' => 'ቋንቋ: $1',

# Edit pages
'savearticle' => 'ፅሑፍ ኣቐምጥ',
'newarticle'  => '(ሓዳስ)',

# History pages
'next'        => 'ዝቕጽል',
'historysize' => '($1 {{PLURAL:$1|ባይታት|ባይታት}})',

# Search results
'prevn'       => 'ናይ ቀደም {{PLURAL:$1|$1}}',
'nextn'       => 'ዝቕጽል {{PLURAL:$1|$1}}',
'powersearch' => 'ድሉይ',

# Preferences page
'preferences'       => 'ኣማረጽቲ',
'mypreferences'     => 'ናተይ ኣማረጽቲ',
'saveprefs'         => 'ኣቐምጥ',
'searchresultshead' => 'ድሉይ',
'savedprefs'        => 'ዘቕረብኩሞ መርኣይ ብትክክል ተቀሚጡ ኣሎ።',
'prefs-files'       => 'ምስልታት',
'youremail'         => 'ኢ-መይል:',
'yourlanguage'      => 'ቋንቋ:',
'email'             => 'ኢ-መይል',

# Groups
'group'       => 'ብሓበር:',
'group-sysop' => 'ሲሶፓት',

'group-sysop-member' => 'ሲሶፕ',

# Recent changes
'hist'          => 'ታሪኽ',
'newpageletter' => 'ሓ',

# Upload
'savefile' => 'ምስሊ ኣቐምጥ',

# Special:ListFiles
'imgfile'        => 'ምስሊ',
'listfiles'      => 'ምስልታት',
'listfiles_name' => 'ሽም',
'listfiles_user' => 'ኣባል',

# File description page
'file-anchor-link' => 'ምስሊ',

# Miscellaneous special pages
'nbytes'            => '$1 {{PLURAL:$1|ባይት|ባይታት}}',
'longpages'         => 'ነዋሕቲ ፅሑፋት',
'listusers'         => 'ኣባላት',
'newpages'          => 'ሓደሽቲ ዛዕባታት',
'newpages-username' => 'ናይ ኣባል ሽም:',

# Book sources
'booksources-go' => 'ኪድ',

# Special:Log
'specialloguserlabel' => 'ኣባል:',

# Special:AllPages
'alphaindexline' => '$1 ናብ $2',
'nextpage'       => 'ዝቕጽል ፅሑፍ ($1)',
'prevpage'       => 'ናይ ቀደም ፅሑፍ ($1)',
'allarticles'    => 'ኵሎም ፅሑፋት',
'allpagesprev'   => 'ናይ ቀደም',
'allpagesnext'   => 'ዝቕጽል',
'allpagessubmit' => 'ኪድ',

# Protect
'pagesize' => '(ባይታት)',

# Undelete
'undelete-search-submit' => 'ድሉይ',

# Contributions
'contribsub2' => 'ን$1 ($2)',

'sp-contributions-submit' => 'ድሉይ',

# Block/unblock
'ipblocklist-submit' => 'ድሉይ',

# Namespace 8 related
'allmessagesname' => 'ሽም',

# Tooltip help for the actions
'tooltip-pt-preferences' => 'ናተይ ኣማረጽቲ',

# Special:NewFiles
'ilsubmit' => 'ድሉይ',

# Metadata
'metadata' => 'ሜታዳታ',

# Multipage image navigation
'imgmultipageprev' => '← ናይ ቀደም ፅሑፍ',
'imgmultipagenext' => 'ዝቕጽል ፅሑፍ →',

# Table pager
'table_pager_next'         => 'ዝቕጽል ፅሑፍ',
'table_pager_prev'         => 'ናይ ቀደም ፅሑፍ',
'table_pager_limit_submit' => 'ኪድ',

# Auto-summaries
'autosumm-new' => 'ሓዳስ ፅሑፍ: $1',

# Size units
'size-bytes'     => '$1 ባይታት',
'size-kilobytes' => '$1 ኪሎባይታት',
'size-megabytes' => '$1 ሜጋባይታት',
'size-gigabytes' => '$1 ጊጋባይታት',

);

==> mediawiki-1.19.15.tar.gz: mediawiki-1.19.15/languages/messages/MessagesTi.php <==
<?php
/** Tigrinya (ትግርኛ)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Blake
 * @author Node ue
 * @author Teak
 */

$messages = array(
'underline-always' => 'ጥራይ',
'underline-never'  => 'ኣይትግበሩ',

# Dates
'sunday'    => 'ሰንበት',
'monday'    => 'ሰኑይ',
'tuesday'   => 'ሰሉስ',
'wednesday' => 'ረብዓ',
'thursday'  => 'ኃሙስ',
'friday'    => 'ዓርቢ',
'saturday'  => 'ቀዳም',
'sun'       => 'ሰንበ',
'mon'       => 'ሰኑይ',
'tue'       => 'ሠሉስ',
'wed'       => 'ረቡዕ',
'thu'       => 'ኃሙስ',
'fri'       => 'ዓርቢ',
'sat'       => 'ቀዳም',
'january'   => 'ትሪ',
'february'  => 'ለካቲት',
'march'     => 'መጋቢት',
'april'     => 'ሚያዝያ',
'may_long'  => 'ግንቦት',
'june'      => 'ሰነ',
'july'      => 'ሓምለ',
'august'    => 'ነሓሰ',
'september' => 'መስከረም',
'october'   => 'ጥቅምቲ',
'november'  => 'ኅዳር',
'december'  => 'ታኅሣሥ',
'jan'       => 'ጃንዩ',
'feb'       => 'ፌብሩ',
'mar'       => 'ማርች',
'apr'       => 'ኤፕረ',
'may'       => 'ሜይ',
'jun'       => 'ጁን',

'about'  => 'ብዛዕባ ብጠቅላላ',
'mypage' => 'ፅሑፈይ',

# Cologne Blue skin
'qbpageoptions' => 'ፅሑፍዚ',
'qbmyoptions'   => 'ፅሑፋተይ',

'help'          => 'ፍንጪ',
'search'        => 'ድሉይ',
'searchbutton'  => 'ድሉይ',
'history'       => 'ናይ ፅሑፍ ታሪኽ',
'history_short' => 'ታሪኽ',
'newpage'       => 'ሓዳስ ፅሑፍ',
'jumptosearch'  => 'ድሉይ',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'ብዛዕባ ዊኪፒዲያ ብጠቅላላ',
'mainpage'             => 'መበገሲ ገጽ',
'mainpage-description' => 'መበገሲ ገጽ',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'    => 'ፅሑፍ',
'nstab-user'    => 'ናይ ፅሑፍ ኣባል',
'nstab-project' => 'ናይ ፅሑፍ ፕሮጀክት',
'nstab-image'   => 'ምስሊ',

# Login and logout pages
'yourname'           => 'ናይ ኣባል ሽም:',
'loginlanguagelabel' => 'ቋንቋ: $1',

# Edit pages
'savearticle' => 'ፅሑፍ ኣቐምጥ',
'newarticle'  => '(ሓዳስ)',

# History pages
'next'        => 'ዝቕጽል',
'historysize' => '($1 {{PLURAL:$1|ባይታት|ባይታት}})',

# Search results
'prevn'       => 'ናይ ቀደም {{PLURAL:$1|$1}}',
'nextn'       => 'ዝቕጽል {{PLURAL:$1|$1}}',
'powersearch' => 'ድሉይ',

# Preferences page
'preferences'       => 'ኣማረጽቲ',
'mypreferences'     => 'ናተይ ኣማረጽቲ',
'saveprefs'         => 'ኣቐምጥ',
'searchresultshead' => 'ድሉይ',
'savedprefs'        => 'ዘቕረብኩሞ መርኣይ ብትክክል ተቀሚጡ ኣሎ።',
'prefs-files'       => 'ምስልታት',
'youremail'         => 'ኢ-መይል:',
'yourlanguage'      => 'ቋንቋ:',
'email'             => 'ኢ-መይል',

# Groups
'group'       => 'ብሓበር:',
'group-sysop' => 'ሲሶፓት',

'group-sysop-member' => '{{GENDER:$1|ሲሶፕ}}',

# Recent changes
'hist'          => 'ታሪኽ',
'newpageletter' => 'ሓ',

# Upload
'savefile' => 'ምስሊ ኣቐምጥ',

# Special:ListFiles
'imgfile'        => 'ምስሊ',
'listfiles'      => 'ምስልታት',
'listfiles_name' => 'ሽም',
'listfiles_user' => 'ኣባል',

# File description page
'file-anchor-link' => 'ምስሊ',

# Miscellaneous special pages
'nbytes'            => '$1 {{PLURAL:$1|ባይት|ባይታት}}',
'longpages'         => 'ነዋሕቲ ፅሑፋት',
'listusers'         => 'ኣባላት',
'newpages'          => 'ሓደሽቲ ዛዕባታት',
'newpages-username' => 'ናይ ኣባል ሽም:',

# Book sources
'booksources-go' => 'ኪድ',

# Special:Log
'specialloguserlabel' => 'ኣባል:',

# Special:AllPages
'alphaindexline' => '$1 ናብ $2',
'nextpage'       => 'ዝቕጽል ፅሑፍ ($1)',
'prevpage'       => 'ናይ ቀደም ፅሑፍ ($1)',
'allarticles'    => 'ኵሎም ፅሑፋት',
'allpagesprev'   => 'ናይ ቀደም',
'allpagesnext'   => 'ዝቕጽል',
'allpagessubmit' => 'ኪድ',

# Protect
'pagesize' => '(ባይታት)',

# Undelete
'undelete-search-submit' => 'ድሉይ',

# Contributions
'contribsub2' => 'ን$1 ($2)',

'sp-contributions-submit' => 'ድሉይ',

# Block/unblock
'ipblocklist-submit' => 'ድሉይ',

# Namespace 8 related
'allmessagesname' => 'ሽም',

# Tooltip help for the actions
'tooltip-pt-preferences' => 'ናተይ ኣማረጽቲ',

# Special:NewFiles
'ilsubmit' => 'ድሉይ',

# Metadata
'metadata' => 'ሜታዳታ',

# Multipage image navigation
'imgmultipageprev' => '← ናይ ቀደም ፅሑፍ',
'imgmultipagenext' => 'ዝቕጽል ፅሑፍ →',

# Table pager
'table_pager_next'         => 'ዝቕጽል ፅሑፍ',
'table_pager_prev'         => 'ናይ ቀደም ፅሑፍ',
'table_pager_limit_submit' => 'ኪድ',

# Auto-summaries
'autosumm-new' => 'ሓዳስ ፅሑፍ: $1',

# Size units
'size-bytes'     => '$1 ባይታት',
'size-kilobytes' => '$1 ኪሎባይታት',
'size-megabytes' => '$1 ሜጋባይታት',
'size-gigabytes' => '$1 ጊጋባይታት',

);
